Crate nrc_mls_sqlite_storage

Crate nrc_mls_sqlite_storage 

SQLite-based storage implementation for Nostr MLS.

This module provides a SQLite-based storage implementation for the Nostr MLS (Messaging Layer Security) crate. It implements the NostrMlsStorageProvider trait, allowing it to be used within the Nostr MLS context.

SQLite-based storage is persistent and will be saved to a file. It’s useful for production applications where data persistence is required.

Modules

error
Error types for the SQLite storage implementation.

Structs

JsonCodec
A codec for JSON serialization and deserialization.
NostrMlsSqliteStorage
A SQLite-based storage implementation for Nostr MLS.